==> no_bloc-0.12.0.tar.gz: lib/src/persisted_bloc.dart <==
import 'package:no_bloc/no_bloc.dart';

import 'bloc.dart';
import 'persistence_service.dart';

/// If bloc is not a singleton then tags must be provided to differentiate between different instances, otherwise different instances will overwrite each other
abstract class AutoPersistedBloc<S> extends PersistedBloc<S> {
  AutoPersistedBloc({S? initialState, tag, BlocMonitor monitor = const BlocEventsPrinter()})
      : super(
          initialState: initialState,
          monitor: monitor,
          tag: tag,
          autoPersistence: true,
          recoverStateOnStart: true,
        );
}

abstract class PersistedBloc<S> extends Bloc<S> {
  final bool _autoPersistence;
  final bool _recoverStateOnStart;
  final Object tag;

  PersistedBloc({
    S? initialState,
    BlocMonitor monitor = const BlocEventsPrinter(),
    this.tag = 0,
    bool autoPersistence = false,
    bool recoverStateOnStart = false,
  })  : _autoPersistence = autoPersistence,
        _recoverStateOnStart = recoverStateOnStart,
        super(
          initialState:
              (autoPersistence && recoverStateOnStart) ? null : initialState,
          monitor: monitor,
        ) {
    if (_autoPersistence && _recoverStateOnStart) {
      persistenceService.get<S>('value').then((got) {
        if (got == null) {
          if (initialState != null) {
            // if initialState is null then the bloc's is already set to busy
            super.setState(initialState, event: 'initializing');
          }
        } else {
          super.setState(got, event: 'recovered_state');
        }
      });
    }
  }

  PersistenceService get persistenceService =>
      PersistenceService('$runtimeType.$tag');

  @override
  void setState(S state, {String? event}) {
    super.setState(state, event: event);

    if (value == state && _autoPersistence) {
      persistenceService.set('value', value);
    }
  }
}

==> no_bloc-0.13.1.tar.gz: lib/src/persisted_bloc.dart <==
import 'package:no_bloc/no_bloc.dart';

import 'bloc.dart';
import 'persistence_service.dart';

/// If bloc is not a singleton then tags must be provided to differentiate between different instances, otherwise different instances will overwrite each other
abstract class AutoPersistedBloc<S> extends PersistedBloc<S> {
  AutoPersistedBloc({S? initialState, tag, BlocMonitor monitor = const BlocEventsPrinter()})
      : super(
          initialState: initialState,
          monitor: monitor,
          tag: tag,
          autoPersistence: true,
          recoverStateOnStart: true,
        );
}

abstract class PersistedBloc<S> extends Bloc<S> {
  final bool _autoPersistence;
  final bool _recoverStateOnStart;
  final Object tag;

  PersistedBloc({
    S? initialState,
    BlocMonitor monitor = const BlocEventsPrinter(),
    this.tag = 0,
    bool autoPersistence = false,
    bool recoverStateOnStart = false,
  })  : _autoPersistence = autoPersistence,
        _recoverStateOnStart = recoverStateOnStart,
        super(
          initialState:
              (autoPersistence && recoverStateOnStart) ? null : initialState,
          monitor: monitor,
        ) {
    if (_autoPersistence && _recoverStateOnStart) {
      persistenceService.get<S>('value').then((got) {
        if (got == null) {
          if (initialState != null) {
            // if initialState is null then the bloc's is already set to busy
            super.setState(initialState, event: 'initializing');
          }
        } else {
          super.setState(got, event: 'recovered_state');
        }
      });
    }
  }

  PersistenceService get persistenceService =>
      PersistenceService('$runtimeType.$tag');

  @override
  void setState(S update, {String? event}) {
    super.setState(update, event: event);

    if (state == update && _autoPersistence) {
      persistenceService.set('value', state);
    }
  }
}
